# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.BaseClasses.WaardenObject import WaardenObject
from otlmow_model.BaseClasses.ComplexField import ComplexField
from otlmow_model.Datatypes.KlBVLaagtype import KlBVLaagtype
from otlmow_model.Datatypes.KwantWrdInTon import KwantWrdInTon, KwantWrdInTonWaarden


# Generated with OTLComplexDatatypeCreator. To modify: extend, do not edit
class DtcProfileerlaagWaarden(WaardenObject):
    def __init__(self):
        WaardenObject.__init__(self)
        self._gewicht = OTLAttribuut(field=KwantWrdInTon,
                                     naam='gewicht',
                                     label='gewicht',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcProfileerlaag.gewicht',
                                     definition='Het gewicht van de profileerlaag in ton.',
                                     owner=self)

        self._laagtype = OTLAttribuut(field=KlBVLaagtype,
                                      naam='laagtype',
                                      label='laagtype',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcProfileerlaag.laagtype',
                                      definition='Het type van de bitumineuze verharding.',
                                      owner=self)

    @property
    def gewicht(self) -> KwantWrdInTonWaarden:
        """Het gewicht van de profileerlaag in ton."""
        return self._gewicht.get_waarde()

    @gewicht.setter
    def gewicht(self, value):
        self._gewicht.set_waarde(value, owner=self._parent)

    @property
    def laagtype(self) -> str:
        """Het type van de bitumineuze verharding."""
        return self._laagtype.get_waarde()

    @laagtype.setter
    def laagtype(self, value):
        self._laagtype.set_waarde(value, owner=self._parent)


# Generated with OTLComplexDatatypeCreator. To modify: extend, do not edit
class DtcProfileerlaag(ComplexField):
    """Complex datatype om extra informatie te capteren van de profilerende laag."""
    naam = 'DtcProfileerlaag'
    label = 'Profileerlaag'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcProfileerlaag'
    definition = 'Complex datatype om extra informatie te capteren van de profilerende laag.'
    waardeObject = DtcProfileerlaagWaarden

    def __str__(self):
        return ComplexField.__str__(self)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.ImplementatieElement.AIMObject import AIMObject
from otlmow_model.BaseClasses.FloatOrDecimalField import FloatOrDecimalField
from otlmow_model.Datatypes.KlHelling import KlHelling
from otlmow_model.Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden
from otlmow_model.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Gronddam(AIMObject, VlakGeometrie):
    """Gronddammen zijn trapeziumvormige constructies bestaande uit zand, grond of steenachtige materialen. De onderkant van de gronddam wordt direct op het bestaand maaiveld aangebracht of op een vooraf aangebrachte grondverbetering. Een gronddam kan volgende functies vervullen: geluidswering, geleiding van dieren, veiligheid en lichtwering."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Gronddam'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        AIMObject.__init__(self)
        VlakGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#GeluidswerendeConstructie', deprecated='2.0.0')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Ecoduct')

        self._basisbreedte = OTLAttribuut(field=KwantWrdInMeter,
                                          naam='basisbreedte',
                                          label='basisbreedte',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Gronddam.basisbreedte',
                                          definition='De breedte van de basis van de gronddam in meter.',
                                          owner=self)

        self._gronddichtheid = OTLAttribuut(field=FloatOrDecimalField,
                                            naam='gronddichtheid',
                                            label='gronddichtheid',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Gronddam.gronddichtheid',
                                            definition='De gronddichtheid van de gronddam.',
                                            owner=self)

        self._hellingAchterzijde = OTLAttribuut(field=KlHelling,
                                                naam='hellingAchterzijde',
                                                label='helling achterzijde',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Gronddam.hellingAchterzijde',
                                                definition='De hellingsgraad van de achterzijde gronddam in kwarten.',
                                                owner=self)

        self._hellingVoorzijde = OTLAttribuut(field=KlHelling,
                                              naam='hellingVoorzijde',
                                              label='helling voorzijde',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Gronddam.hellingVoorzijde',
                                              definition='De hellingsgraad van de voorzijde van de gronddam in kwarten.',
                                              owner=self)

        self._hoogte = OTLAttribuut(field=KwantWrdInMeter,
                                    naam='hoogte',
                                    label='hoogte',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Gronddam.hoogte',
                                    definition='De hoogte van de gronddam in meter.',
                                    owner=self)

        self._kruinbreedte = OTLAttribuut(field=KwantWrdInMeter,
                                          naam='kruinbreedte',
                                          label='kruinbreedte',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Gronddam.kruinbreedte',
                                          definition='De breedte van de kruin van de gronddam in meter.',
                                          owner=self)

    @property
    def basisbreedte(self) -> KwantWrdInMeterWaarden:
        """De breedte van de basis van de gronddam in meter."""
        return self._basisbreedte.get_waarde()

    @basisbreedte.setter
    def basisbreedte(self, value):
        self._basisbreedte.set_waarde(value, owner=self)

    @property
    def gronddichtheid(self) -> float:
        """De gronddichtheid van de gronddam."""
        return self._gronddichtheid.get_waarde()

    @gronddichtheid.setter
    def gronddichtheid(self, value):
        self._gronddichtheid.set_waarde(value, owner=self)

    @property
    def hellingAchterzijde(self) -> str:
        """De hellingsgraad van de achterzijde gronddam in kwarten."""
        return self._hellingAchterzijde.get_waarde()

    @hellingAchterzijde.setter
    def hellingAchterzijde(self, value):
        self._hellingAchterzijde.set_waarde(value, owner=self)

    @property
    def hellingVoorzijde(self) -> str:
        """De hellingsgraad van de voorzijde van de gronddam in kwarten."""
        return self._hellingVoorzijde.get_waarde()

    @hellingVoorzijde.setter
    def hellingVoorzijde(self, value):
        self._hellingVoorzijde.set_waarde(value, owner=self)

    @property
    def hoogte(self) -> KwantWrdInMeterWaarden:
        """De hoogte van de gronddam in meter."""
        return self._hoogte.get_waarde()

    @hoogte.setter
    def hoogte(self, value):
        self._hoogte.set_waarde(value, owner=self)

    @property
    def kruinbreedte(self) -> KwantWrdInMeterWaarden:
        """De breedte van de kruin van de gronddam in meter."""
        return self._kruinbreedte.get_waarde()

    @kruinbreedte.setter
    def kruinbreedte(self, value):
        self._kruinbreedte.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlVariabelDeelType(KeuzelijstField):
    """Types van het variabel deel van een overstortrand."""
    naam = 'KlVariabelDeelType'
    label = 'Variabel deel type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlVariabelDeelType'
    definition = 'Types van het variabel deel van een overstortrand.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlVariabelDeelType'
    options = {
        'overstortplaat': KeuzelijstWaarde(invulwaarde='overstortplaat',
                                           label='overstortplaat',
                                           status='ingebruik',
                                           definitie='overstortplaat',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVariabelDeelType/overstortplaat'),
        'schotbalk': KeuzelijstWaarde(invulwaarde='schotbalk',
                                      label='schotbalk',
                                      status='ingebruik',
                                      definitie='schotbalk',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVariabelDeelType/schotbalk')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlDraagConstrBijzondertransport(KeuzelijstField):
    """De mogelijkheden en manieren waarop een steun geschikt is om bijzonder transport mogelijk te maken."""
    naam = 'KlDraagConstrBijzondertransport'
    label = 'Draagconstructie bijzonder transport'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KlDraagConstrBijzondertransport'
    definition = 'De mogelijkheden en manieren waarop een steun geschikt is om bijzonder transport mogelijk te maken.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlDraagConstrBijzondertransport'
    options = {
        'afkoppelbaar': KeuzelijstWaarde(invulwaarde='afkoppelbaar',
                                         label='afkoppelbaar',
                                         status='ingebruik',
                                         definitie='Het object is afkoppelbaar.',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDraagConstrBijzondertransport/afkoppelbaar'),
        'draaibaar': KeuzelijstWaarde(invulwaarde='draaibaar',
                                      label='draaibaar',
                                      status='ingebruik',
                                      definitie='Het object is draaibaar.',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDraagConstrBijzondertransport/draaibaar'),
        'geen-voorziening': KeuzelijstWaarde(invulwaarde='geen-voorziening',
                                             label='geen voorziening',
                                             status='ingebruik',
                                             definitie='Geen voorziening.',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDraagConstrBijzondertransport/geen-voorziening'),
        'kantelbaar': KeuzelijstWaarde(invulwaarde='kantelbaar',
                                       label='kantelbaar',
                                       status='ingebruik',
                                       definitie='Het object is kantelbaar.',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDraagConstrBijzondertransport/kantelbaar')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.Abstracten.AfwijkendeKantopsluiting import AfwijkendeKantopsluiting
from otlmow_model.BaseClasses.IntegerField import IntegerField


# Generated with OTLClassCreator. To modify: extend, do not edit
class WatergreppelAfw(AfwijkendeKantopsluiting):
    """Afwijkende kantopsluiting, bestemd om water van de verharding op te vangen en af te voeren."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#WatergreppelAfw'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Fundering')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KabelgeleidingEnLeidingBevestiging')

        self._aantalRijenBetonstraatsteen = OTLAttribuut(field=IntegerField,
                                                         naam='aantalRijenBetonstraatsteen',
                                                         label='aantal rijen betonstraatsteen',
                                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#WatergreppelAfw.aantalRijenBetonstraatsteen',
                                                         definition='Het aantal rijen betonstraatsteen waaruit de watergreppel is opgebouwd.',
                                                         owner=self)

    @property
    def aantalRijenBetonstraatsteen(self) -> int:
        """Het aantal rijen betonstraatsteen waaruit de watergreppel is opgebouwd."""
        return self._aantalRijenBetonstraatsteen.get_waarde()

    @aantalRijenBetonstraatsteen.setter
    def aantalRijenBetonstraatsteen(self, value):
        self._aantalRijenBetonstraatsteen.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlEcoEcoductType(KeuzelijstField):
    """Types van ecoduct."""
    naam = 'KlEcoEcoductType'
    label = 'Ecoduct type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlEcoEcoductType'
    definition = 'Types van ecoduct.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlEcoEcoductType'
    options = {
        'bermbrug': KeuzelijstWaarde(invulwaarde='bermbrug',
                                     label='bermbrug',
                                     status='ingebruik',
                                     definitie='Een bestaande, vaak smalle brug met beperkt verkeer waarop de natuur via groene bermen doorloopt.',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlEcoEcoductType/bermbrug'),
        'ecocreaduct': KeuzelijstWaarde(invulwaarde='ecocreaduct',
                                        label='ecocreaduct',
                                        status='ingebruik',
                                        definitie='Een brug hoofdzakelijk in gebruik voor natuur, gecombineerd met zachte recreatie (fietsers, wandelaars, ruiters).',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlEcoEcoductType/ecocreaduct'),
        'ecoveloduct': KeuzelijstWaarde(invulwaarde='ecoveloduct',
                                        label='ecoveloduct',
                                        status='ingebruik',
                                        definitie='Een brug hoofdzakelijk in gebruik voor natuur, gecombineerd met een fietspad.',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlEcoEcoductType/ecoveloduct')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.Abstracten.Proef import Proef
from otlmow_model.Datatypes.KlLEACKerendVermogen import KlLEACKerendVermogen
from otlmow_model.GeometrieTypes.PuntGeometrie import PuntGeometrie
from otlmow_model.GeometrieTypes.LijnGeometrie import LijnGeometrie
from otlmow_model.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class ProefKerendVermogen(Proef, PuntGeometrie, LijnGeometrie, VlakGeometrie):
    """Proef om het vermogen van een voertuigkering te bepalen om een doorbraak bij een bepaald type crash te voorkomen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefKerendVermogen'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    deprecated_version = '2.0.0'

    def __init__(self):
        Proef.__init__(self)
        LijnGeometrie.__init__(self)
        PuntGeometrie.__init__(self)
        VlakGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Geleideconstructie', deprecated='2.0.0')

        self._kerendVermogen = OTLAttribuut(field=KlLEACKerendVermogen,
                                            naam='kerendVermogen',
                                            label='kerend vermogen',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefKerendVermogen.kerendVermogen',
                                            usagenote='Klasse uit gebruik sinds versie 2.0.0 ',
                                            deprecated_version='2.0.0',
                                            definition='Het vermogen van een voertuigkering om een doorbraak bij een bepaald type crash te voorkomen.',
                                            owner=self)

    @property
    def kerendVermogen(self) -> str:
        """Het vermogen van een voertuigkering om een doorbraak bij een bepaald type crash te voorkomen."""
        return self._kerendVermogen.get_waarde()

    @kerendVermogen.setter
    def kerendVermogen(self, value):
        self._kerendVermogen.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlMaaiPeriode(KeuzelijstField):
    """De maand waarin het maaien wordt uitgevoerd."""
    naam = 'KlMaaiPeriode'
    label = 'Maaiperiode'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/levenscyclus#KlMaaiPeriode'
    definition = 'De maand waarin het maaien wordt uitgevoerd.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlMaaiPeriode'
    options = {
        'april': KeuzelijstWaarde(invulwaarde='april',
                                  label='april',
                                  status='ingebruik',
                                  definitie='De maand april.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMaaiPeriode/april'),
        'augustus': KeuzelijstWaarde(invulwaarde='augustus',
                                     label='augustus',
                                     status='ingebruik',
                                     definitie='De maand augustus.',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMaaiPeriode/augustus'),
        'juli': KeuzelijstWaarde(invulwaarde='juli',
                                 label='juli',
                                 status='ingebruik',
                                 definitie='De maand juli.',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMaaiPeriode/juli'),
        'juni': KeuzelijstWaarde(invulwaarde='juni',
                                 label='juni',
                                 status='ingebruik',
                                 definitie='De maand juni.',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMaaiPeriode/juni'),
        'mei': KeuzelijstWaarde(invulwaarde='mei',
                                label='mei',
                                status='ingebruik',
                                definitie='De maand mei.',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMaaiPeriode/mei'),
        'oktober': KeuzelijstWaarde(invulwaarde='oktober',
                                    label='oktober',
                                    status='ingebruik',
                                    definitie='De maand oktober.',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMaaiPeriode/oktober'),
        'september': KeuzelijstWaarde(invulwaarde='september',
                                      label='september',
                                      status='ingebruik',
                                      definitie='De maand september.',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMaaiPeriode/september')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlTransformatorTrafobeveiliging(KeuzelijstField):
    """Type transformatorbeveiliging."""
    naam = 'KlTransformatorTrafobeveiliging'
    label = 'Transformator trafobeveiliging'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlTransformatorTrafobeveiliging'
    definition = 'Type transformatorbeveiliging.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlTransformatorTrafobeveiliging'
    options = {
        'gecombineerd': KeuzelijstWaarde(invulwaarde='gecombineerd',
                                         label='gecombineerd',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTransformatorTrafobeveiliging/gecombineerd'),
        'overdruk': KeuzelijstWaarde(invulwaarde='overdruk',
                                     label='overdruk',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTransformatorTrafobeveiliging/overdruk'),
        'overtemperatuur': KeuzelijstWaarde(invulwaarde='overtemperatuur',
                                            label='overtemperatuur',
                                            status='ingebruik',
                                            definitie='attributen invullen//',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTransformatorTrafobeveiliging/overtemperatuur')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.BaseClasses.BooleanField import BooleanField
from otlmow_model.Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from otlmow_model.Datatypes.DteIPv4Adres import DteIPv4Adres, DteIPv4AdresWaarden
from otlmow_model.Datatypes.KlAudioTransportType import KlAudioTransportType
from otlmow_model.Datatypes.KlIntercomMerk import KlIntercomMerk
from otlmow_model.Datatypes.KlIntercomModelnaam import KlIntercomModelnaam
from otlmow_model.Datatypes.KlIntercomUitvoering import KlIntercomUitvoering
from otlmow_model.BaseClasses.StringField import StringField
from otlmow_model.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class IntercomToestel(AIMNaamObject, PuntGeometrie):
    """Het toestel dat deel uitmaakt van een intercomsysteem en audio- en/of videocommunicatie tussen twee personen mogelijk maakt."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IntercomToestel'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        AIMNaamObject.__init__(self)
        PuntGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BekledingComponent')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ConstructieElement')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Hulppostkast')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Meetmicrofoon')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Montagekast')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Wegkantkast')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#ZuilTGC')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Hulppost')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IntercomServer')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Omvormer')

        self._dnsNaam = OTLAttribuut(field=StringField,
                                     naam='dnsNaam',
                                     label='DNS naam',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IntercomToestel.dnsNaam',
                                     definition='De DNSNaam (ook "volledige domein naam" genoemd ) is een unieke naam binnen het Domain Name System (DNS), het naamgevingssysteem waarmee computers, webservers, diensten en toepassing op een unieke manier kunnen worden geïdentificeerd. Deze bevat zowel de hostname en de top level domein naam bv. 120c8-ar1.belfa.be.',
                                     owner=self)

        self._heeftCamera = OTLAttribuut(field=BooleanField,
                                         naam='heeftCamera',
                                         label='heeft camera',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IntercomToestel.heeftCamera',
                                         definition='Geeft aan of het toestel voorzien is van een camera om naast audio ook video ter verzenden naar een ander toestel in het netwerk.',
                                         owner=self)

        self._heeftVideo = OTLAttribuut(field=BooleanField,
                                        naam='heeftVideo',
                                        label='heeft video',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IntercomToestel.heeftVideo',
                                        definition='Geeft aan of communicatie tussen personen al dan niet via video kan verlopen.',
                                        owner=self)

        self._ipAdres = OTLAttribuut(field=DteIPv4Adres,
                                     naam='ipAdres',
                                     label='IP-adres',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IntercomToestel.ipAdres',
                                     definition='Het IP-adres van het intercomtoestel.',
                                     owner=self)

        self._isInbouw = OTLAttribuut(field=BooleanField,
                                      naam='isInbouw',
                                      label='is inbouw',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IntercomToestel.isInbouw',
                                      definition='Geeft aan of het intercomtoestel een inbouw- of opbouwtoestel is.',
                                      owner=self)

        self._merk = OTLAttribuut(field=KlIntercomMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IntercomToestel.merk',
                                  definition='Het merk van het intercomtoestel.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlIntercomModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IntercomToestel.modelnaam',
                                       definition='De modelnaam van het intercomtoestel.',
                                       owner=self)

        self._oproepnummer = OTLAttribuut(field=StringField,
                                          naam='oproepnummer',
                                          label='oproepnummer',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IntercomToestel.oproepnummer',
                                          definition='Het nummer dat een gebruiker in een verzendend toestel ingeeft om een verbinding te maken met dit, het ontvangend, toestel.',
                                          owner=self)

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IntercomToestel.technischeFiche',
                                             definition='De technische fiche van het intercomtoestel.',
                                             owner=self)

        self._transportType = OTLAttribuut(field=KlAudioTransportType,
                                           naam='transportType',
                                           label='transporttype',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IntercomToestel.transportType',
                                           definition='Geeft het type van (video- en) audiotransport aan van het intercomtoestel binnen het intercomsysteem.',
                                           owner=self)

        self._uitvoering = OTLAttribuut(field=KlIntercomUitvoering,
                                        naam='uitvoering',
                                        label='uitvoering',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IntercomToestel.uitvoering',
                                        definition='Geeft aan welke functie het toestel vervultin het intercomnetwerk.',
                                        owner=self)

    @property
    def dnsNaam(self) -> str:
        """De DNSNaam (ook "volledige domein naam" genoemd ) is een unieke naam binnen het Domain Name System (DNS), het naamgevingssysteem waarmee computers, webservers, diensten en toepassing op een unieke manier kunnen worden geïdentificeerd. Deze bevat zowel de hostname en de top level domein naam bv. 120c8-ar1.belfa.be."""
        return self._dnsNaam.get_waarde()

    @dnsNaam.setter
    def dnsNaam(self, value):
        self._dnsNaam.set_waarde(value, owner=self)

    @property
    def heeftCamera(self) -> bool:
        """Geeft aan of het toestel voorzien is van een camera om naast audio ook video ter verzenden naar een ander toestel in het netwerk."""
        return self._heeftCamera.get_waarde()

    @heeftCamera.setter
    def heeftCamera(self, value):
        self._heeftCamera.set_waarde(value, owner=self)

    @property
    def heeftVideo(self) -> bool:
        """Geeft aan of communicatie tussen personen al dan niet via video kan verlopen."""
        return self._heeftVideo.get_waarde()

    @heeftVideo.setter
    def heeftVideo(self, value):
        self._heeftVideo.set_waarde(value, owner=self)

    @property
    def ipAdres(self) -> DteIPv4AdresWaarden:
        """Het IP-adres van het intercomtoestel."""
        return self._ipAdres.get_waarde()

    @ipAdres.setter
    def ipAdres(self, value):
        self._ipAdres.set_waarde(value, owner=self)

    @property
    def isInbouw(self) -> bool:
        """Geeft aan of het intercomtoestel een inbouw- of opbouwtoestel is."""
        return self._isInbouw.get_waarde()

    @isInbouw.setter
    def isInbouw(self, value):
        self._isInbouw.set_waarde(value, owner=self)

    @property
    def merk(self) -> str:
        """Het merk van het intercomtoestel."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """De modelnaam van het intercomtoestel."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)

    @property
    def oproepnummer(self) -> str:
        """Het nummer dat een gebruiker in een verzendend toestel ingeeft om een verbinding te maken met dit, het ontvangend, toestel."""
        return self._oproepnummer.get_waarde()

    @oproepnummer.setter
    def oproepnummer(self, value):
        self._oproepnummer.set_waarde(value, owner=self)

    @property
    def technischeFiche(self) -> DtcDocumentWaarden:
        """De technische fiche van het intercomtoestel."""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self)

    @property
    def transportType(self) -> str:
        """Geeft het type van (video- en) audiotransport aan van het intercomtoestel binnen het intercomsysteem."""
        return self._transportType.get_waarde()

    @transportType.setter
    def transportType(self, value):
        self._transportType.set_waarde(value, owner=self)

    @property
    def uitvoering(self) -> str:
        """Geeft aan welke functie het toestel vervultin het intercomnetwerk."""
        return self._uitvoering.get_waarde()

    @uitvoering.setter
    def uitvoering(self, value):
        self._uitvoering.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from abc import abstractmethod
from otlmow_model.Classes.Abstracten.Draagconstructie import Draagconstructie
from otlmow_model.Datatypes.KlEMDraagconstructieElekBeveiliging import KlEMDraagconstructieElekBeveiliging


# Generated with OTLClassCreator. To modify: extend, do not edit
class EMDraagconstructie(Draagconstructie):
    """Abstracte voor een elektromechanisch (EM) dragend element (bv. paal, kolom, seinbrug, galgpaal, mast) waaraan EM-toestellen bevestigd kunnen worden."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#EMDraagconstructie'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KabelgeleidingEnLeidingBevestiging')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verlichtingstoestel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Waarschuwingslantaarn')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerlichtingstoestelHgLP')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerlichtingstoestelLED')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerlichtingstoestelMHHP')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerlichtingstoestelNaHP')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerlichtingstoestelNaLP')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerlichtingstoestelTL')

        self._elektrischeBeveiliging = OTLAttribuut(field=KlEMDraagconstructieElekBeveiliging,
                                                    naam='elektrischeBeveiliging',
                                                    label='elektrische beveiliging',
                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#EMDraagconstructie.elektrischeBeveiliging',
                                                    definition='Type elektrische beveiliging aanwezig in de draagconstructie.',
                                                    owner=self)

    @property
    def elektrischeBeveiliging(self) -> str:
        """Type elektrische beveiliging aanwezig in de draagconstructie."""
        return self._elektrischeBeveiliging.get_waarde()

    @elektrischeBeveiliging.setter
    def elektrischeBeveiliging(self, value):
        self._elektrischeBeveiliging.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlNetwerklinkMediumtype(KeuzelijstField):
    """Mogelijke waarden voor het type drager waarlangs data door de link getransporteerd wordt."""
    naam = 'KlNetwerklinkMediumtype'
    label = 'Netwerklink mediumtype'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlNetwerklinkMediumtype'
    definition = 'Mogelijke waarden voor het type drager waarlangs data door de link getransporteerd wordt.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlNetwerklinkMediumtype'
    options = {
        'andere': KeuzelijstWaarde(invulwaarde='andere',
                                   label='andere',
                                   status='ingebruik',
                                   definitie='De link tussen de netwerkpoorten wordt gerealiseerd via een andere dan een optische, UTP, DSL of transportnetwerk verbinding.',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerklinkMediumtype/andere'),
        'dsl': KeuzelijstWaarde(invulwaarde='dsl',
                                label='DSL',
                                status='ingebruik',
                                definitie='De link tussen de netwerkpoorten wordt gerealiseerd via een DSL verbinding.',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerklinkMediumtype/dsl'),
        'optisch': KeuzelijstWaarde(invulwaarde='optisch',
                                    label='optisch',
                                    status='ingebruik',
                                    definitie='De link tussen de netwerkpoorten wordt gerealiseerd via een glasvezelkabel.',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerklinkMediumtype/optisch'),
        'transportnetwerk': KeuzelijstWaarde(invulwaarde='transportnetwerk',
                                             label='transportnetwerk',
                                             status='ingebruik',
                                             definitie='De link tussen de netwerkpoorten wordt gerealiseerd via het optisch transportnetwerk.',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerklinkMediumtype/transportnetwerk'),
        'utp': KeuzelijstWaarde(invulwaarde='utp',
                                label='UTP',
                                status='ingebruik',
                                definitie='De link tussen de netwerkpoorten wordt gerealiseerd via een UTP kabel.',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerklinkMediumtype/utp')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.Classes.Onderdeel.Struweel import Struweel


# Generated with OTLClassCreator. To modify: extend, do not edit
class Vlierstruweel(Struweel):
    """S5 - gewone vlier (dominant)."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Vlierstruweel'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()



# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.Abstracten.LinkendElement import LinkendElement
from otlmow_model.Datatypes.KlTerugslagklepType import KlTerugslagklepType
from otlmow_model.Datatypes.KlTsklepAfsluiterMateriaal import KlTsklepAfsluiterMateriaal
from otlmow_model.Datatypes.KlVormTerugslagklep import KlVormTerugslagklep
from otlmow_model.Datatypes.KwantWrdInMeterTAW import KwantWrdInMeterTAW, KwantWrdInMeterTAWWaarden
from otlmow_model.Datatypes.KwantWrdInMillimeter import KwantWrdInMillimeter, KwantWrdInMillimeterWaarden
from otlmow_model.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Terugslagklep(LinkendElement, PuntGeometrie):
    """Een terugslagklep is een klep die dient om water, vloeistof, granulaat, poeder of gas in één richting door te laten. Meestal duwt het medium de klep bij het heenstromen open en sluit een veer of de zwaartekracht de klep."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Terugslagklep'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        LinkendElement.__init__(self)
        PuntGeometrie.__init__(self)

        self._breedteOpening = OTLAttribuut(field=KwantWrdInMillimeter,
                                            naam='breedteOpening',
                                            label='breedte opening',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Terugslagklep.breedteOpening',
                                            definition='Breedte van de opening die door de terugslagklep wordt afgesloten in millimeter.',
                                            owner=self)

        self._diameter = OTLAttribuut(field=KwantWrdInMillimeter,
                                      naam='diameter',
                                      label='diameter',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Terugslagklep.diameter',
                                      definition='De diameter van de terugslagklep in millimeter.',
                                      owner=self)

        self._hoogteOpening = OTLAttribuut(field=KwantWrdInMillimeter,
                                           naam='hoogteOpening',
                                           label='hoogte opening',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Terugslagklep.hoogteOpening',
                                           definition='De hoogte van de opening die door de terugslagklep wordt afgesloten in millimeter.',
                                           owner=self)

        self._materiaal = OTLAttribuut(field=KlTsklepAfsluiterMateriaal,
                                       naam='materiaal',
                                       label='materiaal',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Terugslagklep.materiaal',
                                       definition='Het materiaal waaruit de terugslagklep is vervaardigd.',
                                       owner=self)

        self._peil = OTLAttribuut(field=KwantWrdInMeterTAW,
                                  naam='peil',
                                  label='peil',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Terugslagklep.peil',
                                  definition='Niveau van de doorlaatopening van de terugslagklep uitgedrukt in meter-TAW.',
                                  owner=self)

        self._type = OTLAttribuut(field=KlTerugslagklepType,
                                  naam='type',
                                  label='type',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Terugslagklep.type',
                                  definition='Bepaalt het type van terugslagklep.',
                                  owner=self)

        self._vorm = OTLAttribuut(field=KlVormTerugslagklep,
                                  naam='vorm',
                                  label='vorm',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Terugslagklep.vorm',
                                  definition='De vorm van de terugslagklep.',
                                  owner=self)

    @property
    def breedteOpening(self) -> KwantWrdInMillimeterWaarden:
        """Breedte van de opening die door de terugslagklep wordt afgesloten in millimeter."""
        return self._breedteOpening.get_waarde()

    @breedteOpening.setter
    def breedteOpening(self, value):
        self._breedteOpening.set_waarde(value, owner=self)

    @property
    def diameter(self) -> KwantWrdInMillimeterWaarden:
        """De diameter van de terugslagklep in millimeter."""
        return self._diameter.get_waarde()

    @diameter.setter
    def diameter(self, value):
        self._diameter.set_waarde(value, owner=self)

    @property
    def hoogteOpening(self) -> KwantWrdInMillimeterWaarden:
        """De hoogte van de opening die door de terugslagklep wordt afgesloten in millimeter."""
        return self._hoogteOpening.get_waarde()

    @hoogteOpening.setter
    def hoogteOpening(self, value):
        self._hoogteOpening.set_waarde(value, owner=self)

    @property
    def materiaal(self) -> str:
        """Het materiaal waaruit de terugslagklep is vervaardigd."""
        return self._materiaal.get_waarde()

    @materiaal.setter
    def materiaal(self, value):
        self._materiaal.set_waarde(value, owner=self)

    @property
    def peil(self) -> KwantWrdInMeterTAWWaarden:
        """Niveau van de doorlaatopening van de terugslagklep uitgedrukt in meter-TAW."""
        return self._peil.get_waarde()

    @peil.setter
    def peil(self, value):
        self._peil.set_waarde(value, owner=self)

    @property
    def type(self) -> str:
        """Bepaalt het type van terugslagklep."""
        return self._type.get_waarde()

    @type.setter
    def type(self, value):
        self._type.set_waarde(value, owner=self)

    @property
    def vorm(self) -> str:
        """De vorm van de terugslagklep."""
        return self._vorm.get_waarde()

    @vorm.setter
    def vorm(self, value):
        self._vorm.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.ImplementatieElement.NaampadObject import NaampadObject
from otlmow_model.Datatypes.DteIPv4Adres import DteIPv4Adres, DteIPv4AdresWaarden
from otlmow_model.BaseClasses.NonNegIntegerField import NonNegIntegerField
from otlmow_model.GeometrieTypes.GeenGeometrie import GeenGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class VLAN(NaampadObject, GeenGeometrie):
    """Binnen de L2 access structuur vormt de VLAN een specifieke virtuele LAN. De toepassingen zijn verbonden met een specifieke VLAN. Rechtstreekse communicatie tussen toepassingen is enkel mogelijk indien deze zijn verbonden met dezelfde VLAN."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#VLAN'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        NaampadObject.__init__(self)
        GeenGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#L2AccessStructuur')

        self._defaultGateway = OTLAttribuut(field=DteIPv4Adres,
                                            naam='defaultGateway',
                                            label='default gateway',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#VLAN.defaultGateway',
                                            definition='Het IP adres van de gateway. Binnen een deelnetwerk is de Gateway de toegangspoort tot het ruimere netwerk.',
                                            owner=self)

        self._ipMask = OTLAttribuut(field=DteIPv4Adres,
                                    naam='ipMask',
                                    label='IP mask',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#VLAN.ipMask',
                                    definition='Bepaalt welke range van IP adressen beschikbaar zijn in een netwerk.',
                                    owner=self)

        self._ipSubnet = OTLAttribuut(field=DteIPv4Adres,
                                      naam='ipSubnet',
                                      label='IP subnet',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#VLAN.ipSubnet',
                                      definition='Identificatie van een IP netwerk binnen een ruimer netwerk.',
                                      owner=self)

        self._vlanId = OTLAttribuut(field=NonNegIntegerField,
                                    naam='vlanId',
                                    label='VLAN identificatienummer',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#VLAN.vlanId',
                                    definition='Identificeert een VLAN met een getal tussen 0 en 4095.',
                                    owner=self)

    @property
    def defaultGateway(self) -> DteIPv4AdresWaarden:
        """Het IP adres van de gateway. Binnen een deelnetwerk is de Gateway de toegangspoort tot het ruimere netwerk."""
        return self._defaultGateway.get_waarde()

    @defaultGateway.setter
    def defaultGateway(self, value):
        self._defaultGateway.set_waarde(value, owner=self)

    @property
    def ipMask(self) -> DteIPv4AdresWaarden:
        """Bepaalt welke range van IP adressen beschikbaar zijn in een netwerk."""
        return self._ipMask.get_waarde()

    @ipMask.setter
    def ipMask(self, value):
        self._ipMask.set_waarde(value, owner=self)

    @property
    def ipSubnet(self) -> DteIPv4AdresWaarden:
        """Identificatie van een IP netwerk binnen een ruimer netwerk."""
        return self._ipSubnet.get_waarde()

    @ipSubnet.setter
    def ipSubnet(self, value):
        self._ipSubnet.set_waarde(value, owner=self)

    @property
    def vlanId(self) -> int:
        """Identificeert een VLAN met een getal tussen 0 en 4095."""
        return self._vlanId.get_waarde()

    @vlanId.setter
    def vlanId(self, value):
        self._vlanId.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlAlgBouwklassegroep(KeuzelijstField):
    """De bouwklassegroepen."""
    naam = 'KlAlgBouwklassegroep'
    label = 'Alg bouwklassegroep'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlAlgBouwklassegroep'
    definition = 'De bouwklassegroepen.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlAlgBouwklassegroep'
    options = {
        'B1': KeuzelijstWaarde(invulwaarde='B1',
                               label='B1',
                               status='ingebruik',
                               definitie='B1',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgBouwklassegroep/B1'),
        'B10': KeuzelijstWaarde(invulwaarde='B10',
                                label='B10',
                                status='ingebruik',
                                definitie='B10',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgBouwklassegroep/B10'),
        'B2': KeuzelijstWaarde(invulwaarde='B2',
                               label='B2',
                               status='ingebruik',
                               definitie='B2',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgBouwklassegroep/B2'),
        'B3': KeuzelijstWaarde(invulwaarde='B3',
                               label='B3',
                               status='ingebruik',
                               definitie='B3',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgBouwklassegroep/B3'),
        'B4': KeuzelijstWaarde(invulwaarde='B4',
                               label='B4',
                               status='ingebruik',
                               definitie='B4',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgBouwklassegroep/B4'),
        'B5': KeuzelijstWaarde(invulwaarde='B5',
                               label='B5',
                               status='ingebruik',
                               definitie='B5',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgBouwklassegroep/B5'),
        'B6': KeuzelijstWaarde(invulwaarde='B6',
                               label='B6',
                               status='ingebruik',
                               definitie='B6',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgBouwklassegroep/B6'),
        'B7': KeuzelijstWaarde(invulwaarde='B7',
                               label='B7',
                               status='ingebruik',
                               definitie='B7',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgBouwklassegroep/B7'),
        'B8': KeuzelijstWaarde(invulwaarde='B8',
                               label='B8',
                               status='ingebruik',
                               definitie='B8',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgBouwklassegroep/B8'),
        'B9': KeuzelijstWaarde(invulwaarde='B9',
                               label='B9',
                               status='ingebruik',
                               definitie='B9',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgBouwklassegroep/B9'),
        'BF': KeuzelijstWaarde(invulwaarde='BF',
                               label='BF',
                               status='ingebruik',
                               definitie='BF',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgBouwklassegroep/BF')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.BaseClasses.WaardenObject import WaardenObject
from otlmow_model.BaseClasses.ComplexField import ComplexField
from otlmow_model.Datatypes.KlBSSRandafwerking import KlBSSRandafwerking
from otlmow_model.Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden


# Generated with OTLComplexDatatypeCreator. To modify: extend, do not edit
class DtcBSSRandafwerkingWaarden(WaardenObject):
    def __init__(self):
        WaardenObject.__init__(self)
        self._lengteRandafwerking = OTLAttribuut(field=KwantWrdInMeter,
                                                 naam='lengteRandafwerking',
                                                 label='lengte randafwerking',
                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcBSSRandafwerking.lengteRandafwerking',
                                                 definition='De lengte in meter van de randafwerking.',
                                                 owner=self)

        self._randafwerking = OTLAttribuut(field=KlBSSRandafwerking,
                                           naam='randafwerking',
                                           label='randafwerking',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcBSSRandafwerking.randafwerking',
                                           definition='De wijze waarop de rand van de bestrating is afgewerkt.',
                                           owner=self)

    @property
    def lengteRandafwerking(self) -> KwantWrdInMeterWaarden:
        """De lengte in meter van de randafwerking."""
        return self._lengteRandafwerking.get_waarde()

    @lengteRandafwerking.setter
    def lengteRandafwerking(self, value):
        self._lengteRandafwerking.set_waarde(value, owner=self._parent)

    @property
    def randafwerking(self) -> str:
        """De wijze waarop de rand van de bestrating is afgewerkt."""
        return self._randafwerking.get_waarde()

    @randafwerking.setter
    def randafwerking(self, value):
        self._randafwerking.set_waarde(value, owner=self._parent)


# Generated with OTLComplexDatatypeCreator. To modify: extend, do not edit
class DtcBSSRandafwerking(ComplexField):
    """Complex datatype voor de afwerking van de rand van een betonstraatsteenverharding."""
    naam = 'DtcBSSRandafwerking'
    label = 'Betonstraatsteenafwerking'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcBSSRandafwerking'
    definition = 'Complex datatype voor de afwerking van de rand van een betonstraatsteenverharding.'
    waardeObject = DtcBSSRandafwerkingWaarden

    def __str__(self):
        return ComplexField.__str__(self)




import inspect
import warnings
from typing import Type, Optional

from otlmow_model.BaseClasses.RelationInteractor import RelationInteractor
from otlmow_model.Classes.ImplementatieElement.RelatieObject import RelatieObject
from otlmow_model.Exceptions.RelationDeprecationWarning import RelationDeprecationWarning
from otlmow_model.Helpers.AssetCreator import dynamic_create_instance_from_uri


def is_valid_relation_instance(source: RelationInteractor, relation_instance: RelatieObject,
                               target: RelationInteractor) -> bool:
    """
    Verifies if a relation would be valid between a source and a target, given the instance of that relation

    :param source: the intended source for the relation
    :type: RelationInteractor
    :param relation_instance: the instance of the relation
    :type: RelatieObject
    :param target: the intended target for the relation
    :type: RelationInteractor
    :return: 'True' if the relation would be valid, 'False' otherwise
    """
    return is_valid_relation(source=source, target=target,
                                               relation_type=type(relation_instance))


def is_valid_relation(relation_type: Type[RelatieObject], source: Optional[RelationInteractor] = None,
                      source_typeURI: Optional[str] = None, target: Optional[RelationInteractor] = None,
                      target_typeURI: Optional[str] = None) -> bool:
    """
    Verifies if a relation would be valid between a source and a target, given a relation_type type. Exactly one of
    source or source_typeURI must not be None. Exactly one of target or target_typeURI must not be None.

    :param relation_type: the intended type of the relation
    :param source: the intended source for the relation_type
    :param source_typeURI: the typeURI of the intended source for the relation
    :param target: the intended source for the relation
    :param target_typeURI: the typeURI of the intended target for the relation
    :return: 'True' if the relation would be valid, 'False' otherwise
    """

    if source is not None and source_typeURI is not None:
        warnings.warn('both source and source_typeURI are not None. Overriding source by instantiating it',
                      RuntimeWarning)
        source = dynamic_create_instance_from_uri(source_typeURI)
    if target is not None and target_typeURI is not None:
        warnings.warn('both target and target_typeURI are not None. Overriding source by instantiating it',
                      RuntimeWarning)
        target = dynamic_create_instance_from_uri(source_typeURI)

    if source is not None and source_typeURI is None:
        source_typeURI = source.typeURI
    if source_typeURI is None:
        raise ValueError('Exactly one of source or source_typeURI needs to be not None.')

    if target is not None and target_typeURI is None:
        target_typeURI = target.typeURI
    if target_typeURI is None:
        raise ValueError('Exactly one of target or target_typeURI needs to be not None.')

    if 'lgc.' in source_typeURI or 'lgc.' in target_typeURI:
        return True

    if source is None:
        source = dynamic_create_instance_from_uri(source_typeURI)

    if relation_type.typeURI not in source._valid_relations:
        return False

    targets = source._valid_relations[relation_type.typeURI].keys()
    if target_typeURI in targets:
        deprecated_value = source._valid_relations[relation_type.typeURI][target_typeURI]
        if deprecated_value != '':
            warnings.warn(
                message=f'the relation_type of type {relation_type.typeURI} between assets of types '
                        f'{source_typeURI} and {target_typeURI} is deprecated since version {deprecated_value}',
                category=RelationDeprecationWarning)
        return True

    if target is None:
        target = dynamic_create_instance_from_uri(target_typeURI)
    bases = inspect.getmro(type(target))
    for base in bases:
        base_type_uri = _get_member(base, 'typeURI')
        if base_type_uri in targets:
            deprecated_value = source._valid_relations[relation_type.typeURI][base_type_uri]
            if deprecated_value != '':
                warnings.warn(
                    message=f'the relation_type of type {relation_type.typeURI} between assets of types '
                            f'{source_typeURI} and {target_typeURI} is deprecated since version {deprecated_value}',
                    category=RelationDeprecationWarning)
            return True

    return False


def _get_member(obj, name):
    return next(iter([member for _name, member in inspect.getmembers(obj) if name == _name]), None)



# coding=utf-8
from otlmow_model.Classes.Abstracten.VRModuleMetFirmware import VRModuleMetFirmware


# Generated with OTLClassCreator. To modify: extend, do not edit
class VRBeveiligingskaart(VRModuleMetFirmware):
    """Processorkaart die de beveiligings- en bewakingsfunctie op zich neemt. Indien bij controle van de signalen een gevaarlijke status vastgesteld wordt, zorgt deze voor een omschakeling van het signaalsysteem naar een veilige status, nl. gecontroleerde uitschakeling"""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VRBeveiligingskaart'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlBetrokkenheidRol(KeuzelijstField):
    """Keuzelijst met mogelijke waarden voor de rol waarmee een agent betrokken is bij een object."""
    naam = 'KlBetrokkenheidRol'
    label = 'Betrokkenheid rol'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlBetrokkenheidRol'
    definition = 'Keuzelijst met mogelijke waarden voor de rol waarmee een agent betrokken is bij een object.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlBetrokkenheidRol'
    options = {
        'beheerder': KeuzelijstWaarde(invulwaarde='beheerder',
                                      label='beheerder',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBetrokkenheidRol/beheerder'),
        'berekende-beheerder': KeuzelijstWaarde(invulwaarde='berekende-beheerder',
                                                label='berekende beheerder',
                                                status='ingebruik',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBetrokkenheidRol/berekende-beheerder'),
        'eigenaar': KeuzelijstWaarde(invulwaarde='eigenaar',
                                     label='eigenaar',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBetrokkenheidRol/eigenaar'),
        'installatieverantwoordelijke': KeuzelijstWaarde(invulwaarde='installatieverantwoordelijke',
                                                         label='Installatieverantwoordelijke',
                                                         status='ingebruik',
                                                         definitie='De installatieverantwoordelijke is de persoon, aangeduid door de werkgever, om de verantwoordelijkheid voor de exploitatie van de elektrische installatie op zich te nemen. Indien nodig kan hij die verantwoordelijkheid wel gedeeltelijk op andere personen overdragen. Concreet is hij op de hoogte van de eventuele afwijkende situaties en gaat, in overleg met de werkverantwoordelijke, na of de nodige maatregelen genomen worden om op een veilige manier te werken met een dergelijke installatie.',
                                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBetrokkenheidRol/installatieverantwoordelijke'),
        'keuringsinstantie': KeuzelijstWaarde(invulwaarde='keuringsinstantie',
                                              label='keuringsinstantie',
                                              status='ingebruik',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBetrokkenheidRol/keuringsinstantie'),
        'klant': KeuzelijstWaarde(invulwaarde='klant',
                                  label='klant',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBetrokkenheidRol/klant'),
        'leidinggevende': KeuzelijstWaarde(invulwaarde='leidinggevende',
                                           label='leidinggevende',
                                           status='ingebruik',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBetrokkenheidRol/leidinggevende'),
        'lid': KeuzelijstWaarde(invulwaarde='lid',
                                label='lid',
                                status='ingebruik',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBetrokkenheidRol/lid'),
        'schadebeheerder': KeuzelijstWaarde(invulwaarde='schadebeheerder',
                                            label='schadebeheerder',
                                            status='ingebruik',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBetrokkenheidRol/schadebeheerder'),
        'suborganisatie-van': KeuzelijstWaarde(invulwaarde='suborganisatie-van',
                                               label='suborganisatie van',
                                               status='ingebruik',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBetrokkenheidRol/suborganisatie-van'),
        'toezicht-onderhoud': KeuzelijstWaarde(invulwaarde='toezicht-onderhoud',
                                               label='toezicht onderhoud',
                                               status='ingebruik',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBetrokkenheidRol/toezicht-onderhoud'),
        'toezichter': KeuzelijstWaarde(invulwaarde='toezichter',
                                       label='toezichter',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBetrokkenheidRol/toezichter'),
        'toezichtsgroep': KeuzelijstWaarde(invulwaarde='toezichtsgroep',
                                           label='toezichtsgroep',
                                           status='ingebruik',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBetrokkenheidRol/toezichtsgroep'),
        'verantwoordelijke-reiniging': KeuzelijstWaarde(invulwaarde='verantwoordelijke-reiniging',
                                                        label='verantwoordelijke reiniging',
                                                        status='ingebruik',
                                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBetrokkenheidRol/verantwoordelijke-reiniging')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.ImplementatieElement.AIMObject import AIMObject
from otlmow_model.Datatypes.KlBinnenverlichtingstoestelSoortLamp import KlBinnenverlichtingstoestelSoortLamp
from otlmow_model.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Aanstraalverlichting(AIMObject, PuntGeometrie):
    """Lamp met fel gebundeld licht die het verlicht gebied duidelijk zichtbaar maakt."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Aanstraalverlichting'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        AIMObject.__init__(self)
        PuntGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BekledingComponent')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Vluchtdeur')

        self._type = OTLAttribuut(field=KlBinnenverlichtingstoestelSoortLamp,
                                  naam='type',
                                  label='type',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Aanstraalverlichting.type',
                                  definition='Geeft het soort lamp mee dat voor de verlichting zorgt.',
                                  owner=self)

    @property
    def type(self) -> str:
        """Geeft het soort lamp mee dat voor de verlichting zorgt."""
        return self._type.get_waarde()

    @type.setter
    def type(self, value):
        self._type.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlNSB(KeuzelijstField):
    """Het mogelijke huidige natuurbeelden of natuurstreefbeelden."""
    naam = 'KlNSB'
    label = 'Natuurstreefbeeld'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlNSB'
    definition = 'Het mogelijke huidige natuurbeelden of natuurstreefbeelden.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlNSB'
    options = {
        '2130': KeuzelijstWaarde(invulwaarde='2130',
                                 label='2130',
                                 status='ingebruik',
                                 definitie='zanddoddengras, kleverige reigersbek, ruw vergeet-mij-nietje, kruipend stalkruid, zandhoornbloem, duinfakkelgras, liggende asperge, duindravik, duinviooltje, kegelsilene, ruwe klaver, duin- en gewimperd langbaardgras, lathyruswikke, geel walstro, grote tijm, geel zonneroosje, liggend bergvlas, nachtsilene, walstrobremraap, kalkbedstro, zachte haver, voorjaarsganzerik, duindravik, gestreepte klaver, wondklaver',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/2130'),
        '2330': KeuzelijstWaarde(invulwaarde='2330',
                                 label='2330',
                                 status='ingebruik',
                                 definitie='vroege haver, klein vogelpootje, zilverhaver, klein tasjeskruid, dwergviltkruid, eekhoorngras, zandblauwtje, veldereprijs, hazenpootje, eenjarige hardbloem, rode schijnspurrie, akkerviooltje, zandmuur, reigersbek, spurrie, straatgras, zandraket, vroegeling, kleine leeuwenklauw, zachte ooievaarsbek, klein streepzaad, gewoon langbaardgras, zandhoornbloem, slofhak ',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/2330'),
        '4030': KeuzelijstWaarde(invulwaarde='4030',
                                 label='4030',
                                 status='ingebruik',
                                 definitie='meidoorn spp., sleedoorn en rozen',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/4030'),
        '6120': KeuzelijstWaarde(invulwaarde='6120',
                                 label='6120',
                                 status='ingebruik',
                                 definitie='cipreswolfsmelk, geoorde zuring, gestreepte klaver, grote tijm, handjesgras, harige ratelaar, hemelsleutel, kaal breukkruid, kleine pimpernel, kleine ratelaar, knikkende distel, knolbeemdgras, kruisdistel, kweekdravik, moeslook, ronde ooievaarsbek, rozetkruidkers, rozetsteenkers, sikkelklaver, slangenlook, smalle raai, tripmadam, veldsalie, viltganzerik, voorjaarszegge, wit en zacht vetkruid, zachte haver, zeepkruid',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/6120'),
        '6210-Hk': KeuzelijstWaarde(invulwaarde='6210-Hk',
                                    label='6210 Hk',
                                    status='ingebruik',
                                    definitie='blauwgras, bergdravik, duifkruid, grote centaurie, ruige scheefkelk, geel zonneroosje, kleine pimpernel, Kalkwalstro, gevinde kortsteel, aarddistel, smal fakkelgras, driedistel',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/6210-Hk'),
        '6230-Ha': KeuzelijstWaarde(invulwaarde='6230-Ha',
                                    label='6230 Ha',
                                    status='ingebruik',
                                    definitie='Idem als hierboven maar met 3 soorten aanwezig uit: bosdroogbloem, dicht havikskruid, dwergviltkruid, eekhoorngras, geel walstro, grasklokje, steenanjer, viltganzerik, kleine tijm, zandblauwtje',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/6230-Ha'),
        '6230-Hmo': KeuzelijstWaarde(invulwaarde='6230-Hmo',
                                     label='6230 Hmo',
                                     status='ingebruik',
                                     definitie='blauwe knoop, blauwe zegge, bleeksporig bosviooltje, bleke zegge, borstelgras, dicht havikskruid, echte guldenroede, fijn schapengras, fraai hertshooi, gelobde maanvaren, gevlekte orchis, heidekartelblad, hondsviooltje, kleine tijm, klokjesgentiaan, knollathyrus, kruipganzerik, liggend walstro, liggende vleugeltjesbloem, mannetjesereprijs, spits havikskruid, stijf havikskruid, stijve ogentroost, tandjesgras, tormentil, trekrus, tweenervige zegge, veelbloemige veldbies, zaagblad, klokjesgentiaan, heidekartelblad, welriekende nachtorchis',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/6230-Hmo'),
        '6230-Hn': KeuzelijstWaarde(invulwaarde='6230-Hn',
                                    label='6230 Hn',
                                    status='ingebruik',
                                    definitie='blauwe knoop, blauwe zegge, bleeksporig bosviooltje, bleke zegge, borstelgras, dicht havikskruid, echte guldenroede, fijn schapengras, fraai hertshooi, gelobde maanvaren, gevlekte orchis, heidekartelblad, hondsviooltje, kleine tijm, klokjesgentiaan, knollathyrus, kruipganzerik, liggend walstro, liggende vleugeltjesbloem, mannetjesereprijs, spits havikskruid, stijf havikskruid, stijve ogentroost, tandjesgras, tormentil, trekrus, tweenervige zegge, veelbloemige veldbies, zaagblad, klokjesgentiaan, heidekartelblad, welriekende nachtorchis',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/6230-Hn'),
        '6430': KeuzelijstWaarde(invulwaarde='6430',
                                 label='6430',
                                 status='ingebruik',
                                 definitie='oeverzegge, moeraszegge, gele lis, wolfspoot, hop, harig wilgenroosje, gewone smeerwortel, haagwinde, moerasandoorn, groot hoefblad, koninginnenkruid, grote kattenstaart, geoord helmkruid, gevleugeld helmkruid, viltige bastaardwederik, groot warkruid, moerasmelkdistel en heemst',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/6430'),
        '6510Hu': KeuzelijstWaarde(invulwaarde='6510Hu',
                                   label='6510Hu',
                                   status='ingebruik',
                                   definitie='aardaker, beemdkroon, beemdooievaarsbek, bevertjes, gele morgenster, gewone agrimonie, gewone rolklaver, gewone vogelmelk, glad walstro, goudhaver, graslathyrus, groot streepzaad, grote bevernel, grote pimpernel, gulden boterbloem, gulden sleutelbloem, klavervreter, kleine bevernel, kleine ratelaar, knolboterbloem, knolsteenbreek, knoopkruid, kraailook, margriet, muskuskaasjeskruid, naakte lathyrus, rapunzelklokje, ruige leeuwentand, veldlathyrus, veldsalie, vijfdelig kaasjeskruid en zachte haver, grote ratelaar, vertakte leeuwentand, vierzadige wikke',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/6510Hu'),
        '6510Huk': KeuzelijstWaarde(invulwaarde='6510Huk',
                                    label='6510Huk',
                                    status='ingebruik',
                                    definitie='aarddistel, beemdkroon, bevertjes, driedistel, duifkruid, geelhartje, gevinde kortsteel, gewone agrimonie, goudhaver, grote tijm, gulden sleutelbloem, kattendoorn, kleine bevernel, kleine pimpernel, knolboterbloem, kruipend stalkruid, ruige leeuwentand, ruige weegbree, voorjaarszegge, wilde marjolein, zachte haver, zeegroene zegge',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/6510Huk'),
        '9110': KeuzelijstWaarde(invulwaarde='9110',
                                 label='9110',
                                 status='ingebruik',
                                 definitie='Veldbies-Beukenbossen',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/9110'),
        '9120': KeuzelijstWaarde(invulwaarde='9120',
                                 label='9120',
                                 status='ingebruik',
                                 definitie='Eiken-Beukenbossen op zure bodems ',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/9120'),
        '9130': KeuzelijstWaarde(invulwaarde='9130',
                                 label='9130',
                                 status='ingebruik',
                                 definitie='Eiken-Beukenbossen met Wilde hyacint en ParelgrasBeukenbossen',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/9130'),
        '9150': KeuzelijstWaarde(invulwaarde='9150',
                                 label='9150',
                                 status='ingebruik',
                                 definitie='9150',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/9150'),
        '9160': KeuzelijstWaarde(invulwaarde='9160',
                                 label='9160',
                                 status='ingebruik',
                                 definitie='Essen-Eikenbossen zonder Wilde hyacint',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/9160'),
        '9190': KeuzelijstWaarde(invulwaarde='9190',
                                 label='9190',
                                 status='ingebruik',
                                 definitie='Oude Eiken-Berkenbossen op zeer voedselarm zand',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/9190'),
        '91E0': KeuzelijstWaarde(invulwaarde='91E0',
                                 label='91E0',
                                 status='ingebruik',
                                 definitie='grove den (min 50% van de boomlaag) + > 0,5 ha + oud bos + kenmerkende soorten: Lelietje-van-dalen, dalkruid, ruige veldbies, bosgierstgras, hulst, wilde kamperfoelie, gladde witbol, dubbelloof, valse salie, pilzegge, adelaarsvaren, grote veldbies, witte veldbies, gewone salomonszegel, bosanemoon, witte klaverzurig',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/91E0'),
        'andere-Cd': KeuzelijstWaarde(invulwaarde='andere-Cd',
                                      label='andere Cd',
                                      status='ingebruik',
                                      definitie='andere cd',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/andere-Cd'),
        'andere-Cm': KeuzelijstWaarde(invulwaarde='andere-Cm',
                                      label='andere Cm',
                                      status='ingebruik',
                                      definitie='andere cm',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/andere-Cm'),
        'andere-Cp': KeuzelijstWaarde(invulwaarde='andere-Cp',
                                      label='andere Cp',
                                      status='ingebruik',
                                      definitie='struikheide, dopheide, blauwe bosbes, stekelbrem, kruipbrem',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/andere-Cp'),
        'andere-Ha': KeuzelijstWaarde(invulwaarde='andere-Ha',
                                      label='andere Ha',
                                      status='ingebruik',
                                      definitie='akkerhoornbloem, gewone veldbies, gewoon biggenkruid, gewoon duizendblad, gewoon struisgras, hazenpootje, klein vogelpootje, kleine klaver, kleine leeuwentand, knolboterbloem, muizenoor, schapenzuring, smalle weegbree, vroege haver, zilverhaver',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/andere-Ha'),
        'andere-Hj': KeuzelijstWaarde(invulwaarde='andere-Hj',
                                      label='andere Hj',
                                      status='ingebruik',
                                      definitie='andere hj',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/andere-Hj'),
        'andere-Hp': KeuzelijstWaarde(invulwaarde='andere-Hp',
                                      label='andere Hp',
                                      status='ingebruik',
                                      definitie='geen soorten van de twee volgende types (rbbkam & rbbvos) aanwezig.',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/andere-Hp'),
        'andere-Hr': KeuzelijstWaarde(invulwaarde='andere-Hr',
                                      label='andere Hr',
                                      status='ingebruik',
                                      definitie='grote brandnetel, kleefkruid, ridderzuring, akkerdistel, speerdistel, gewone berenklauw, fluitenkruid, bramen, klit, jacobskruiskruid, ijle dravik, dolle kervel, kweek, kropaar, haagwinde, zevenblad',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/andere-Hr'),
        'andere-Hu': KeuzelijstWaarde(invulwaarde='andere-Hu',
                                      label='andere Hu',
                                      status='ingebruik',
                                      definitie='Voldoet niet aan de voorwaarden voor 6510 (< 7 soorten uit 6510)',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/andere-Hu'),
        'andere-Mr': KeuzelijstWaarde(invulwaarde='andere-Mr',
                                      label='andere Mr',
                                      status='ingebruik',
                                      definitie='riet en soorten uit R3',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/andere-Mr'),
        'andere-Sz': KeuzelijstWaarde(invulwaarde='andere-Sz',
                                      label='andere Sz',
                                      status='ingebruik',
                                      definitie='Andere Sz',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/andere-Sz'),
        'rbbha': KeuzelijstWaarde(invulwaarde='rbbha',
                                  label='rbbha',
                                  status='ingebruik',
                                  definitie='Soortenrijk struisgrasland met vrij algemene soorten',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/rbbha'),
        'rbbhc': KeuzelijstWaarde(invulwaarde='rbbhc',
                                  label='rbbhc',
                                  status='ingebruik',
                                  definitie='echte koekoeksbloem, grote ratelaar, kruipend zenegroen, moeras/zompvergeet-me-nietje, dotterbloem, kale jonker, lidrus, moerasrolklaver, moeraswalstro, egelboterbloem, pinksterbloem, slanke sleutelbloem, tweerijige zegge, gewone waterbies, heelblaadjes, penningkruid, pijptorkruid, zomprus',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/rbbhc'),
        'rbbhf': KeuzelijstWaarde(invulwaarde='rbbhf',
                                  label='rbbhf',
                                  status='ingebruik',
                                  definitie='wilde bertram, grote wederik, melkeppe, hennegras, ruw walstro, wateraardbei, moerasbeemdgras, veenpluis, veenmos en/of zwarte zegge, moerasspirea',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/rbbhf'),
        'rbbhu': KeuzelijstWaarde(invulwaarde='rbbhu',
                                  label='rbbhu',
                                  status='ingebruik',
                                  definitie='min. 2 soorten abundant aanwezig uit:  kruipend zenegroen, pinksterbloem, tweerijige zegge, moesdistel, ruwe smele, lidrus, moerasspirea, beemdlangbloem, moerasrolklaver, echte koekoeksbloem, penningkruid, moeras/zompvergeet-mij-nietje, grote ratelaar, waterkruiskruid, smeerwortel, vogelwikke OF trosdravik of grote trosdravik aanwezig',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/rbbhu'),
        'rbbkam': KeuzelijstWaarde(invulwaarde='rbbkam',
                                   label='rbbkam',
                                   status='ingebruik',
                                   definitie='kamgras en/of veldgerst abundant én aantal soorten >;15.',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/rbbkam'),
        'rbbmr': KeuzelijstWaarde(invulwaarde='rbbmr',
                                  label='rbbmr',
                                  status='ingebruik',
                                  definitie='riet en soorten uit R3; kenmerken en kenmerkende soorten voor rbbmr worden in 2017 door INBO uitgewerkt.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/rbbmr'),
        'rbbppm': KeuzelijstWaarde(invulwaarde='rbbppm',
                                   label='rbbppm',
                                   status='ingebruik',
                                   definitie='Structuurrijke, oude bestanden van Grove den met een minimale leeftijd van tachtig jaar.',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/rbbppm'),
        'rbbsf': KeuzelijstWaarde(invulwaarde='rbbsf',
                                  label='rbbsf',
                                  status='ingebruik',
                                  definitie='Boomlaag zoals hierboven + opp > 0,5 ha + oud bos met kenmerkende soorten van oud bos (bijlage 3), schraalland of heide (verder te bepalen met Bossleutel) ',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/rbbsf'),
        'rbbsg': KeuzelijstWaarde(invulwaarde='rbbsg',
                                  label='rbbsg',
                                  status='ingebruik',
                                  definitie='Dit type staat voor begroeiingen waar Brem veel voorkomt of domineert. Soms komt ook de veel zeldzamere Gaspeldoorn voor. Bremstruwelen bedekken zelden volledige percelen.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/rbbsg'),
        'rbbsp': KeuzelijstWaarde(invulwaarde='rbbsp',
                                  label='rbbsp',
                                  status='ingebruik',
                                  definitie='Dit zijn struwelen die gedomineerd worden door houtige, doornige soorten zoals Sleedoorn, meidoorn (eenstijlige en tweestijlige) en/of rozen. We vinden dedoornige struwelen vooral terug als houtkanten en uitgegroeide hagen. ',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/rbbsp'),
        'rbbzil': KeuzelijstWaarde(invulwaarde='rbbzil',
                                   label='rbbzil',
                                   status='ingebruik',
                                   definitie='zilt grasland: aardbeiklaver, akkerkers, getand vlotgras, gewone waterbies, heelblaadjes, klein vlooienkruid, kruipend moerasscherm, moeras/zompvergeetme-nietje, moeraszoutgras (polderstreek), penningkruid, pijptorkruid, platte rus, polei, rode ogentroost, slanke waterbies, smalle rolklaver (polderstreek), valse voszegge, watermunt, zeegroene rus, zilte rus, zilte zegge (polderstreek), zilverschoon, zomprus',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNSB/rbbzil')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlHoppinzuilType(KeuzelijstField):
    """De types van een analoge hoppinzuil."""
    naam = 'KlHoppinzuilType'
    label = 'Hoppinzuil type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlHoppinzuilType'
    definition = 'De types van een analoge hoppinzuil.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlHoppinzuilType'
    options = {
        'analoog-groot': KeuzelijstWaarde(invulwaarde='analoog-groot',
                                          label='Analoog groot',
                                          status='ingebruik',
                                          definitie='Hoppinzuil met een minimale afmeting van 55x10x280 cm waarop de veranderlijke informatie analoog (op papier/sticker) wordt weergegeven.',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlHoppinzuilType/analoog-groot'),
        'analoog-mini': KeuzelijstWaarde(invulwaarde='analoog-mini',
                                         label='Analoog mini',
                                         status='ingebruik',
                                         definitie='Hoppinzuil met een minimale afmeting van 40x3x200 cm waarop de veranderlijke informatie analoog (op papier/sticker) wordt weergegeven.',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlHoppinzuilType/analoog-mini')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlEcoAfschermingtype(KeuzelijstField):
    """Types van afscherming."""
    naam = 'KlEcoAfschermingtype'
    label = 'Afschermingtype'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlEcoAfschermingtype'
    definition = 'Types van afscherming.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlEcoAfschermingtype'
    options = {
        'heidematten': KeuzelijstWaarde(invulwaarde='heidematten',
                                        label='heidematten',
                                        status='ingebruik',
                                        definitie='Een afscherming bestaande uit heidematten.',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlEcoAfschermingtype/heidematten'),
        'houten': KeuzelijstWaarde(invulwaarde='houten',
                                   label='houten',
                                   status='ingebruik',
                                   definitie='Een afscherming bestaande uit houten schermen.',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlEcoAfschermingtype/houten'),
        'metalen': KeuzelijstWaarde(invulwaarde='metalen',
                                    label='metalen',
                                    status='ingebruik',
                                    definitie='Een afscherming bestaande uit metalen schermen.',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlEcoAfschermingtype/metalen')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.BaseClasses.WaardenObject import WaardenObject
from otlmow_model.BaseClasses.ComplexField import ComplexField
from otlmow_model.Datatypes.KlProfielhoogtemaat import KlProfielhoogtemaat
from otlmow_model.Datatypes.KlProfielsoort import KlProfielsoort


# Generated with OTLComplexDatatypeCreator. To modify: extend, do not edit
class DtcProfieltypeWaarden(WaardenObject):
    def __init__(self):
        WaardenObject.__init__(self)
        self._profielhoogtemaat = OTLAttribuut(field=KlProfielhoogtemaat,
                                               naam='profielhoogtemaat',
                                               label='profielhoogtemaat',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcProfieltype.profielhoogtemaat',
                                               definition='Voorgedefinieerde hoogtemaat van een profiel.',
                                               owner=self)

        self._profielsoort = OTLAttribuut(field=KlProfielsoort,
                                          naam='profielsoort',
                                          label='profielsoort',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcProfieltype.profielsoort',
                                          definition='Het type profiel (de meest genormeerde types).',
                                          owner=self)

    @property
    def profielhoogtemaat(self) -> str:
        """Voorgedefinieerde hoogtemaat van een profiel."""
        return self._profielhoogtemaat.get_waarde()

    @profielhoogtemaat.setter
    def profielhoogtemaat(self, value):
        self._profielhoogtemaat.set_waarde(value, owner=self._parent)

    @property
    def profielsoort(self) -> str:
        """Het type profiel (de meest genormeerde types)."""
        return self._profielsoort.get_waarde()

    @profielsoort.setter
    def profielsoort(self, value):
        self._profielsoort.set_waarde(value, owner=self._parent)


# Generated with OTLComplexDatatypeCreator. To modify: extend, do not edit
class DtcProfieltype(ComplexField):
    """Complex datatype om de hoogtemaat en de soort van het profiel in te geven."""
    naam = 'DtcProfieltype'
    label = 'Profieltype'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcProfieltype'
    definition = 'Complex datatype om de hoogtemaat en de soort van het profiel in te geven.'
    waardeObject = DtcProfieltypeWaarden

    def __str__(self):
        return ComplexField.__str__(self)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.BaseClasses.BooleanField import BooleanField
from otlmow_model.Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from otlmow_model.Datatypes.KlTankKleur import KlTankKleur
from otlmow_model.Datatypes.KlTankMateriaal import KlTankMateriaal
from otlmow_model.Datatypes.KlTankMerk import KlTankMerk
from otlmow_model.Datatypes.KlTankModelnaam import KlTankModelnaam
from otlmow_model.Datatypes.KlTankOpstelling import KlTankOpstelling
from otlmow_model.Datatypes.KlTankVorm import KlTankVorm
from otlmow_model.Datatypes.KwantWrdInCentimeter import KwantWrdInCentimeter, KwantWrdInCentimeterWaarden
from otlmow_model.Datatypes.KwantWrdInKubiekeMeter import KwantWrdInKubiekeMeter, KwantWrdInKubiekeMeterWaarden
from otlmow_model.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Tank(AIMNaamObject, VlakGeometrie):
    """Een constructie voor het opslaan van goederen, typisch in vloeibare of gasvormige toestand, zoals water, brandstof, aardgas, lucht, etc."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Tank'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        AIMNaamObject.__init__(self)
        VlakGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Niveaumeting')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Zoutbijlaadplaats')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Persleiding')

        self._diameter = OTLAttribuut(field=KwantWrdInCentimeter,
                                      naam='diameter',
                                      label='diameter',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Tank.diameter',
                                      definition='De diameter in centimeter van de tank.',
                                      owner=self)

        self._heeftTrapconstructie = OTLAttribuut(field=BooleanField,
                                                  naam='heeftTrapconstructie',
                                                  label='heeft trapconstructie',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Tank.heeftTrapconstructie',
                                                  definition='Geeft aan of het object al dan niet een trapconstructie bevat.',
                                                  owner=self)

        self._kleur = OTLAttribuut(field=KlTankKleur,
                                   naam='kleur',
                                   label='kleur',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Tank.kleur',
                                   definition='De kleur van een tank.',
                                   owner=self)

        self._lengte = OTLAttribuut(field=KwantWrdInCentimeter,
                                    naam='lengte',
                                    label='lengte',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Tank.lengte',
                                    definition='Lengte in centimeter van de tank. ',
                                    owner=self)

        self._materiaal = OTLAttribuut(field=KlTankMateriaal,
                                       naam='materiaal',
                                       label='materiaal',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Tank.materiaal',
                                       definition='Het materiaal waaruit de tank vervaardigd is.',
                                       owner=self)

        self._merk = OTLAttribuut(field=KlTankMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Tank.merk',
                                  definition='Het merk van de tank.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlTankModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Tank.modelnaam',
                                       definition='De modelnaam van de tank.',
                                       owner=self)

        self._opstelHoogte = OTLAttribuut(field=KwantWrdInCentimeter,
                                          naam='opstelHoogte',
                                          label='opstelhoogte',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Tank.opstelHoogte',
                                          definition='De hoogte in centimeter beschikbaar tussen het grondoppervlak en de tank.',
                                          owner=self)

        self._opstelling = OTLAttribuut(field=KlTankOpstelling,
                                        naam='opstelling',
                                        label='oriëntatie',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Tank.opstelling',
                                        definition='De oriëntatie van de opstelling van de tank.',
                                        owner=self)

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Tank.technischeFiche',
                                             definition='De technische fiche van de tank.',
                                             owner=self)

        self._volume = OTLAttribuut(field=KwantWrdInKubiekeMeter,
                                    naam='volume',
                                    label='volume',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Tank.volume',
                                    definition='Het volume in kubieke meter van de tank.',
                                    owner=self)

        self._vorm = OTLAttribuut(field=KlTankVorm,
                                  naam='vorm',
                                  label='vorm',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Tank.vorm',
                                  definition='De vorm van de tank.',
                                  owner=self)

    @property
    def diameter(self) -> KwantWrdInCentimeterWaarden:
        """De diameter in centimeter van de tank."""
        return self._diameter.get_waarde()

    @diameter.setter
    def diameter(self, value):
        self._diameter.set_waarde(value, owner=self)

    @property
    def heeftTrapconstructie(self) -> bool:
        """Geeft aan of het object al dan niet een trapconstructie bevat."""
        return self._heeftTrapconstructie.get_waarde()

    @heeftTrapconstructie.setter
    def heeftTrapconstructie(self, value):
        self._heeftTrapconstructie.set_waarde(value, owner=self)

    @property
    def kleur(self) -> str:
        """De kleur van een tank."""
        return self._kleur.get_waarde()

    @kleur.setter
    def kleur(self, value):
        self._kleur.set_waarde(value, owner=self)

    @property
    def lengte(self) -> KwantWrdInCentimeterWaarden:
        """Lengte in centimeter van de tank. """
        return self._lengte.get_waarde()

    @lengte.setter
    def lengte(self, value):
        self._lengte.set_waarde(value, owner=self)

    @property
    def materiaal(self) -> str:
        """Het materiaal waaruit de tank vervaardigd is."""
        return self._materiaal.get_waarde()

    @materiaal.setter
    def materiaal(self, value):
        self._materiaal.set_waarde(value, owner=self)

    @property
    def merk(self) -> str:
        """Het merk van de tank."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """De modelnaam van de tank."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)

    @property
    def opstelHoogte(self) -> KwantWrdInCentimeterWaarden:
        """De hoogte in centimeter beschikbaar tussen het grondoppervlak en de tank."""
        return self._opstelHoogte.get_waarde()

    @opstelHoogte.setter
    def opstelHoogte(self, value):
        self._opstelHoogte.set_waarde(value, owner=self)

    @property
    def opstelling(self) -> str:
        """De oriëntatie van de opstelling van de tank."""
        return self._opstelling.get_waarde()

    @opstelling.setter
    def opstelling(self, value):
        self._opstelling.set_waarde(value, owner=self)

    @property
    def technischeFiche(self) -> DtcDocumentWaarden:
        """De technische fiche van de tank."""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self)

    @property
    def volume(self) -> KwantWrdInKubiekeMeterWaarden:
        """Het volume in kubieke meter van de tank."""
        return self._volume.get_waarde()

    @volume.setter
    def volume(self, value):
        self._volume.set_waarde(value, owner=self)

    @property
    def vorm(self) -> str:
        """De vorm van de tank."""
        return self._vorm.get_waarde()

    @vorm.setter
    def vorm(self, value):
        self._vorm.set_waarde(value, owner=self)



# coding=utf-8
from abc import abstractmethod, ABC


# Generated with OTLClassCreator. To modify: extend, do not edit
class Toegangselement(ABC):
    """Abstracte voor het groeperen van de relaties voor elementen die toegang verschaffen tot een behuizing of locatie."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Toegangselement'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Behuizing')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Buitenkast')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Inloopbehuizing')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Gebouw')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Lokaal')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Afsluiting')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Cabine')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Contactpunt')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Container')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Doorverbinddoos')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HSCabine')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Hulppostkast')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IndoorKast')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Lockerkast')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Montagekast')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#TechnischePut')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Wegkantkast')

        pass



import base64
import re
import warnings
from typing import Type, Optional

from typing.re import Match

from otlmow_model.BaseClasses.RelationInteractor import RelationInteractor
from otlmow_model.Classes.Agent import Agent
from otlmow_model.Classes.ImplementatieElement.RelatieObject import RelatieObject
from otlmow_model.Classes.Onderdeel.HeeftBetrokkene import HeeftBetrokkene
from otlmow_model.Exceptions.CouldNotCreateRelationError import CouldNotCreateRelationError
from otlmow_model.Helpers.AssetCreator import dynamic_create_instance_from_uri
from otlmow_model.Helpers.GenericHelper import get_ns_and_name_from_uri
from otlmow_model.Helpers.RelationValidator import is_valid_relation


def validate_guid(uuid: str) -> Optional[Match]:
    uuid_pattern = "^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$"
    return re.match(uuid_pattern, uuid)


def encode_short_uri(short_uri: str) -> str:
    short_uri_bytes = short_uri.encode('ascii')
    base64_bytes = base64.b64encode(short_uri_bytes)
    base64_short_uri = base64_bytes.decode('ascii')
    while base64_short_uri.endswith('='):
        base64_short_uri = base64_short_uri[:-1]
    return base64_short_uri


def create_relation(relation_type: Type[RelatieObject], source: Optional[RelationInteractor] = None,
                    target: Optional[RelationInteractor] = None,
                    source_uuid: Optional[str] = None, source_typeURI: Optional[str] = None,
                    target_uuid: Optional[str] = None, target_typeURI: Optional[str] = None,
                    class_directory: str = None) -> Optional[RelatieObject]:
    """
    Instantiates a relation, if valid, between instantiated objects, given a specific relation type.
    Instead of instantiated objects, valid guids and typeURI's can be provided, for source and/or target.

    :param relation_type: the relation type of the relation to be created
    :type: RelatieObject
    :param source: the intended source for the relation
    :type: RelationInteractor
    :param target: the intended target for the relation
    :type: RelationInteractor
    :param source_uuid: the uuid of the intended source for the relation
    :type: str
    :param source_typeURI: the typeURI of the intended source for the relation
    :type: str
    :param target_uuid: the uuid of the intended target for the relation
    :type: str
    :param target_typeURI: the typeURI of the intended target for the relation
    :type: str
    :param class_directory: directory where the class modules are located, defaults to OTLMOW.OTLModel.Classes
    :type: str

    :return: Returns the instantiated relation between the given source and target, or None if the relation is invalid.
    :rtype: RelatieObject or None
    """
    if source is None and (source_typeURI is None or source_uuid is None):
        raise ValueError('Exactly one of source or (source_typeURI + source_uuid) needs to be not None.')
    if target is None and (target_typeURI is None or target_uuid is None):
        raise ValueError('Exactly one of target or (target_typeURI + target_uuid) needs to be not None.')

    if source is not None and source_typeURI is not None:
        warnings.warn('both source and source_typeURI are not None. Using source and ignoring source_typeURI.',
                      RuntimeWarning)
    if target is not None and target_typeURI is not None:
        warnings.warn('both target and target_typeURI are not None. Using source and ignoring target_typeURI.',
                      RuntimeWarning)

    source_is_legacy, target_is_legacy = False, False
    source_aim_id, target_aim_id = None, None

    if source is None:
        if not validate_guid(source_uuid):
            raise ValueError('source_uuid is not a valid guid format.')

        ns, name = get_ns_and_name_from_uri(source_typeURI)
        encoded_uri = encode_short_uri(f'{ns}#{name}')
        source_aim_id = f'{source_uuid}-{encoded_uri}'

        if 'lgc.' in source_typeURI:
            source_is_legacy = True
        else:
            source = dynamic_create_instance_from_uri(source_typeURI, directory=class_directory)
            source.assetId.identificator = source_aim_id
            source.assetId.toegekendDoor = 'AWV'

    if target is None:
        if not validate_guid(target_uuid):
            raise ValueError('target_uuid is not a valid guid format.')

        ns, name = get_ns_and_name_from_uri(target_typeURI)
        encoded_uri = encode_short_uri(f'{ns}#{name}')
        target_aim_id = f'{target_uuid}-{encoded_uri}'

        if 'lgc.' in target_typeURI:
            target_is_legacy = True
        else:
            target = dynamic_create_instance_from_uri(target_typeURI, directory=class_directory)
            target.assetId.identificator = target_aim_id
            target.assetId.toegekendDoor = 'AWV'

    if not (source_is_legacy or target_is_legacy):
        valid = is_valid_relation(source=source, target=target, relation_type=relation_type)
        if not valid:
            raise CouldNotCreateRelationError("Can't create an invalid relation_type, please validate relations first")

    relation_type = dynamic_create_instance_from_uri(class_uri=relation_type.typeURI,
                                                     directory=class_directory)

    if not source_is_legacy and source.assetId.identificator is None:
        raise AttributeError('In order to create a relation_type, the source needs to have a valid assetId '
                             '(source.assetId.identificator)')
    if not target_is_legacy and target.assetId.identificator is None:
        raise AttributeError(
            'In order to create a relation_type, the target needs to have a valid assetId '
            '(target.assetId.identificator)')

    relation_id = ''
    if source_is_legacy:
        relation_type.bronAssetId.identificator = source_aim_id
        relation_type.bronAssetId.toegekendDoor = 'AWV'
        relation_id += source_aim_id
    else:
        relation_type.bronAssetId.identificator = source.assetId.identificator
        relation_type.bronAssetId.toegekendDoor = source.assetId.toegekendDoor
        relation_id += source.assetId.identificator

    relation_id += '_-_'

    if target_is_legacy:
        relation_type.doelAssetId.identificator = target_aim_id
        relation_type.doelAssetId.toegekendDoor = 'AWV'
        relation_id += target_aim_id
    else:
        relation_type.doelAssetId.identificator = target.assetId.identificator
        relation_type.doelAssetId.toegekendDoor = target.assetId.toegekendDoor
        relation_id += target.assetId.identificator

    relation_type.assetId.identificator = relation_id
    relation_type.assetId.toegekendDoor = 'OTLMOW'

    if relation_type.bronAssetId.toegekendDoor != 'AWV':
        relation_type.bron.typeURI = source.typeURI
    if relation_type.doelAssetId.toegekendDoor != 'AWV':
        relation_type.doel.typeURI = target.typeURI
    return relation_type


def create_betrokkenerelation(rol: str, source: Optional[RelationInteractor] = None,
                              target: Optional[Agent] = None,
                              source_uuid: Optional[str] = None, source_typeURI: Optional[str] = None,
                              target_uuid: Optional[str] = None, target_typeURI: Optional[str] = None,
                              class_directory: str = None) -> Optional[HeeftBetrokkene]:
    relation = create_relation(source=source, target=target, source_uuid=source_uuid, source_typeURI=source_typeURI,
                               target_uuid=target_uuid, target_typeURI=target_typeURI, class_directory=class_directory,
                               relation_type=HeeftBetrokkene)
    relation.rol = rol
    return relation



# coding=utf-8
from datetime import date
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.Abstracten.Brandvoorziening import Brandvoorziening
from otlmow_model.BaseClasses.DateField import DateField
from otlmow_model.Datatypes.KlBrandhaspelMerk import KlBrandhaspelMerk
from otlmow_model.Datatypes.KlBrandhaspelModelnaam import KlBrandhaspelModelnaam
from otlmow_model.Datatypes.KwantWrdInCentimeter import KwantWrdInCentimeter, KwantWrdInCentimeterWaarden
from otlmow_model.Datatypes.KwantWrdInKubiekeMeter import KwantWrdInKubiekeMeter, KwantWrdInKubiekeMeterWaarden
from otlmow_model.Datatypes.KwantWrdInKubiekeMeterPerSeconde import KwantWrdInKubiekeMeterPerSeconde, KwantWrdInKubiekeMeterPerSecondeWaarden
from otlmow_model.Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden


# Generated with OTLClassCreator. To modify: extend, do not edit
class Brandhaspel(Brandvoorziening):
    """Een brandslang met spuitmond,opgerold op een haspel."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Brandhaspel'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Hulppostkast')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Hulppost')

        self._buitendiameter = OTLAttribuut(field=KwantWrdInCentimeter,
                                            naam='buitendiameter',
                                            label='buitendiameter',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Brandhaspel.buitendiameter',
                                            definition='Buitendiameter van de slang op de haspel.',
                                            owner=self)

        self._keuringsdatum = OTLAttribuut(field=DateField,
                                           naam='keuringsdatum',
                                           label='keuringsdatum',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Brandhaspel.keuringsdatum',
                                           definition='Laatste datum waarop de haspel gekeurd is.',
                                           owner=self)

        self._maximaalDebiet = OTLAttribuut(field=KwantWrdInKubiekeMeter,
                                            naam='maximaalDebiet',
                                            label='maximaalDebiet',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Brandhaspel.maximaalDebiet',
                                            usagenote='Attribuut uit gebruik sinds versie 2.0.0 ',
                                            deprecated_version='2.0.0',
                                            definition='Het maximale debiet dat door de slang en spuitmond kan stromen.',
                                            owner=self)

        self._maximaalVolumedebiet = OTLAttribuut(field=KwantWrdInKubiekeMeterPerSeconde,
                                                  naam='maximaalVolumedebiet',
                                                  label='maximaal volumedebiet',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Brandhaspel.maximaalVolumedebiet',
                                                  definition='Het maximale debiet dat per tijdseenheid door de slang en spuitmond kan stromen.',
                                                  owner=self)

        self._merk = OTLAttribuut(field=KlBrandhaspelMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Brandhaspel.merk',
                                  definition='Het merk van de brandhaspel.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlBrandhaspelModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Brandhaspel.modelnaam',
                                       definition='De modelnaam van de brandhaspel.',
                                       owner=self)

        self._slangLengte = OTLAttribuut(field=KwantWrdInMeter,
                                         naam='slangLengte',
                                         label='slanglengte',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Brandhaspel.slangLengte',
                                         definition='Nuttige lengte van de brandslang op de haspel.',
                                         owner=self)

    @property
    def buitendiameter(self) -> KwantWrdInCentimeterWaarden:
        """Buitendiameter van de slang op de haspel."""
        return self._buitendiameter.get_waarde()

    @buitendiameter.setter
    def buitendiameter(self, value):
        self._buitendiameter.set_waarde(value, owner=self)

    @property
    def keuringsdatum(self) -> date:
        """Laatste datum waarop de haspel gekeurd is."""
        return self._keuringsdatum.get_waarde()

    @keuringsdatum.setter
    def keuringsdatum(self, value):
        self._keuringsdatum.set_waarde(value, owner=self)

    @property
    def maximaalDebiet(self) -> KwantWrdInKubiekeMeterWaarden:
        """Het maximale debiet dat door de slang en spuitmond kan stromen."""
        return self._maximaalDebiet.get_waarde()

    @maximaalDebiet.setter
    def maximaalDebiet(self, value):
        self._maximaalDebiet.set_waarde(value, owner=self)

    @property
    def maximaalVolumedebiet(self) -> KwantWrdInKubiekeMeterPerSecondeWaarden:
        """Het maximale debiet dat per tijdseenheid door de slang en spuitmond kan stromen."""
        return self._maximaalVolumedebiet.get_waarde()

    @maximaalVolumedebiet.setter
    def maximaalVolumedebiet(self, value):
        self._maximaalVolumedebiet.set_waarde(value, owner=self)

    @property
    def merk(self) -> str:
        """Het merk van de brandhaspel."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """De modelnaam van de brandhaspel."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)

    @property
    def slangLengte(self) -> KwantWrdInMeterWaarden:
        """Nuttige lengte van de brandslang op de haspel."""
        return self._slangLengte.get_waarde()

    @slangLengte.setter
    def slangLengte(self, value):
        self._slangLengte.set_waarde(value, owner=self)



# coding=utf-8
from abc import abstractmethod
from otlmow_model.Classes.Abstracten.Signalisatie import Signalisatie
from otlmow_model.Classes.ImplementatieElement.AIMObject import AIMObject


# Generated with OTLClassCreator. To modify: extend, do not edit
class Straatmeubilair(AIMObject, Signalisatie):
    """Abstracte bedoeld om het straatmeubilair onder 1 noemer te houden."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Straatmeubilair'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        AIMObject.__init__(self)
        Signalisatie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AndereLaag')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AndereVerharding')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ArtificieleLaag')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Bestrating')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Laag')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#LaagBouwklasse')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BeschermingWapening')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BestratingVanBetonstraatsteen')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BestratingVanBetontegel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BestratingVanGebakkenStraatsteen')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BestratingVanGrasbetontegel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BestratingVanKassei')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BestratingVanMozaiekkei')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BestratingVanNatuursteentegel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bestrijking')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BitumineuzeLaag')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Cementbetonverharding')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#ColloidaalBeton')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Dolomietverharding')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DunneOverlaging')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#GeexpandeerdPolystyreen')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Geotextiel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Grond')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Noppendrainage')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#OnbegroeidVoorkomen')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Onderbouw')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Schanskorf')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#ScheurremmendeLaag')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Slemlaag')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Steenslagverharding')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stortdraad')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stortsteen')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Ternairmengselverharding')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerhardingGrasKunststofplaat')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Walsbetonverharding')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#WaterdoorlatendeBestrating')



# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.ImplementatieElement.NaampadObject import NaampadObject
from otlmow_model.BaseClasses.IntegerField import IntegerField
from otlmow_model.Datatypes.KlNetwerklinkMediumtype import KlNetwerklinkMediumtype
from otlmow_model.BaseClasses.StringField import StringField
from otlmow_model.GeometrieTypes.GeenGeometrie import GeenGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Link(NaampadObject, GeenGeometrie):
    """Het (glasvezel) traject tussen twee toestellen (NetwerkElementen) die rechtstreeks met mekaar communiceren."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Link'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        NaampadObject.__init__(self)
        GeenGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Pad')

        self._geleidingsgroepTnummer = OTLAttribuut(field=IntegerField,
                                                    naam='geleidingsgroepTnummer',
                                                    label='geleidingsgroep T-nummer',
                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Link.geleidingsgroepTnummer',
                                                    definition='T-nummer van de geleidingsgroep in de kabelnet toepassing.',
                                                    owner=self)

        self._mediumtype = OTLAttribuut(field=KlNetwerklinkMediumtype,
                                        naam='mediumtype',
                                        label='mediumtype',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Link.mediumtype',
                                        definition='Geeft aan hoe de verbinding tussen Netwerkelementen fysiek gerealiseerd wordt',
                                        owner=self)

        self._ring = OTLAttribuut(field=StringField,
                                  naam='ring',
                                  label='ring',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Link.ring',
                                  definition='Naam van de ringstructuur in het transport netwerk.',
                                  owner=self)

    @property
    def geleidingsgroepTnummer(self) -> int:
        """T-nummer van de geleidingsgroep in de kabelnet toepassing."""
        return self._geleidingsgroepTnummer.get_waarde()

    @geleidingsgroepTnummer.setter
    def geleidingsgroepTnummer(self, value):
        self._geleidingsgroepTnummer.set_waarde(value, owner=self)

    @property
    def mediumtype(self) -> str:
        """Geeft aan hoe de verbinding tussen Netwerkelementen fysiek gerealiseerd wordt"""
        return self._mediumtype.get_waarde()

    @mediumtype.setter
    def mediumtype(self, value):
        self._mediumtype.set_waarde(value, owner=self)

    @property
    def ring(self) -> str:
        """Naam van de ringstructuur in het transport netwerk."""
        return self._ring.get_waarde()

    @ring.setter
    def ring(self, value):
        self._ring.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlGeotextielType(KeuzelijstField):
    """Types van geotextiel."""
    naam = 'KlGeotextielType'
    label = 'Geotextiel type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlGeotextielType'
    definition = 'Types van geotextiel.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlGeotextielType'
    options = {
        'anti-vraatdoek': KeuzelijstWaarde(invulwaarde='anti-vraatdoek',
                                           label='anti-vraatdoek',
                                           status='ingebruik',
                                           definitie='anti-vraatdoek',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlGeotextielType/anti-vraatdoek'),
        'bescherming': KeuzelijstWaarde(invulwaarde='bescherming',
                                        label='bescherming',
                                        status='ingebruik',
                                        definitie='bescherming/wapening',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlGeotextielType/bescherming'),
        'erosiewerend': KeuzelijstWaarde(invulwaarde='erosiewerend',
                                         label='erosiewerend',
                                         status='ingebruik',
                                         definitie='erosiewerend',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlGeotextielType/erosiewerend'),
        'niet-geweven-geotextiel': KeuzelijstWaarde(invulwaarde='niet-geweven-geotextiel',
                                                    label='niet-geweven geotextiel',
                                                    status='ingebruik',
                                                    definitie='niet-geweven geotextiel',
                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlGeotextielType/niet-geweven-geotextiel'),
        'wapening': KeuzelijstWaarde(invulwaarde='wapening',
                                     label='wapening',
                                     status='ingebruik',
                                     definitie='bescherming/wapening',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlGeotextielType/wapening')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.BaseClasses.OTLField import OTLField
from otlmow_model.BaseClasses.WaardenObject import WaardenObject
from otlmow_model.BaseClasses.FloatOrDecimalField import FloatOrDecimalField
from otlmow_model.BaseClasses.StringField import StringField


# Generated with OTLPrimitiveDatatypeCreator. To modify: extend, do not edit
class KwantWrdInDecimaleGradenWaarden(WaardenObject):
    def __init__(self):
        WaardenObject.__init__(self)
        self._standaardEenheid = OTLAttribuut(field=StringField,
                                              naam='standaardEenheid',
                                              label='standaard eenheid',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#KwantWrdInDecimaleGraden.standaardEenheid',
                                              usagenote='"deg"^^cdt:ucumunit',
                                              readonly=True,
                                              constraints='"deg"^^cdt:ucumunit',
                                              definition='De standaard eenheid bij dit datatype is uitgedrukt in decimale graden.',
                                              owner=self)

        self._waarde = OTLAttribuut(field=FloatOrDecimalField,
                                    naam='waarde',
                                    label='waarde',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#KwantWrdInDecimaleGraden.waarde',
                                    definition='Bevat een getal die bij het datatype hoort.',
                                    owner=self)

    @property
    def standaardEenheid(self) -> str:
        """De standaard eenheid bij dit datatype is uitgedrukt in decimale graden."""
        return self._standaardEenheid.usagenote.split('"')[1]

    @property
    def waarde(self) -> float:
        """Bevat een getal die bij het datatype hoort."""
        return self._waarde.get_waarde()

    @waarde.setter
    def waarde(self, value):
        self._waarde.set_waarde(value, owner=self._parent)


# Generated with OTLPrimitiveDatatypeCreator. To modify: extend, do not edit
class KwantWrdInDecimaleGraden(OTLField):
    """Een kwantitatieve waarde die een getal in decimale graden uitdrukt."""
    naam = 'KwantWrdInDecimaleGraden'
    label = 'Kwantitatieve waarde in decimale graden'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#KwantWrdInDecimaleGraden'
    definition = 'Een kwantitatieve waarde die een getal in decimale graden uitdrukt.'
    waarde_shortcut_applicable = True
    waardeObject = KwantWrdInDecimaleGradenWaarden

    def __str__(self):
        return OTLField.__str__(self)

